class LarkBody {
    body;
    /**
     * 是否为Lark消息体
     */
    isLarkBody = true;
    /**
     * 是否为事件消息
     */
    isEvent = false;
    /**
     * 是否为Action消息
     */
    isAction = false;
    /**
     * 事件类型
     */
    eventType;
    /**
     * 是否为消息事件
     */
    isMessageEvent;
    /**
     * 消息类型
     */
    msgType;
    /**
     * 用户Id
     */
    userId;
    /**
     * 用户OpenId
     */
    openId;
    /**
     * 文本内容
     */
    msgText = "";
    /**
     * 原始文本内容
     */
    rawMsgText = "";
    /**
     * 聊天类型
     */
    chatType;
    /**
     * 是否为P2P聊天
     */
    isP2P;
    /**
     * 是否在群聊中
     */
    isInGroup;
    /**
     * 艾特信息
     */
    mentions;
    /**
     * 艾特的机器人
     */
    mentionedRobot;
    /**
     * Action类型
     */
    actionType;
    /**
     * Action参数
     */
    actionValue;
    /**
     * Action选项
     */
    actionOption;
    /**
     * 对话流Id
     */
    chatId = "";
    /**
     * 消息Id
     */
    messageId = "";
    /**
     * 构造函数
     * @param body 事件消息体或Action消息体
     */
    constructor(body) {
        this.body = body;
        this.isEvent = this.getIsEvent(body);
        this.isAction = this.getIsAction(body);
        if (this.isEvent) {
            const eventBody = body;
            this.eventType = this.getEventType(eventBody);
            this.isMessageEvent = this.getIsMessageEvent(eventBody);
            this.msgType = this.getMsgType(eventBody);
            this.msgText = this.getMsgText(eventBody);
            this.rawMsgText = this.getRawMsgText(eventBody);
            this.chatType = this.getChatType(eventBody);
            this.isP2P = this.chatType === "p2p";
            this.isInGroup = this.chatType === "group";
            this.mentions = this.getMentions(eventBody);
            this.mentionedRobot = this.getMentionedRobot(eventBody);
        }
        if (this.isAction) {
            const actionBody = body;
            this.actionType = this.getActionType(actionBody);
            this.actionValue = this.getActionValue(actionBody);
            this.actionOption = this.getActionOption(actionBody);
        }
        this.chatId = this.getChatId(body);
        this.messageId = this.getMessageId(body);
        this.userId = this.getUserId(body);
        this.openId = this.getOpenId(body);
        this.isLarkBody = this.isEvent || this.isAction;
    }
    /**
     * 获取事件类型
     * @param body 事件消息体
     * @returns 事件类型
     */
    getEventType(body) {
        return body?.header?.event_type;
    }
    /**
     * 是否为消息事件
     * @param body 消息事件体
     * @returns
     */
    getIsMessageEvent(body) {
        return body?.header?.event_type === "im.message.receive_v1";
    }
    /**
     * 是否为事件消息
     * @param body 事件消息体
     * @returns 是否为事件消息
     */
    getIsEvent(body) {
        return !!body?.event;
    }
    /**
     * 是否为Action消息
     * @param body Action消息体
     * @returns 是否为Action消息
     */
    getIsAction(body) {
        return !!body?.action;
    }
    /**
     * 获取事件文本类型
     * @param body 事件消息体
     * @returns 事件文本类型
     */
    getMsgType(body) {
        return body?.event?.message?.message_type;
    }
    /**
     * 获取文本内容并剔除艾特信息
     * @param body 事件消息体
     * @returns 文本内容
     */
    getMsgText(body) {
        try {
            const { text } = JSON.parse(body?.event?.message?.content);
            // 去掉@_user_1相关的内容，例如 '@_user_1 测试' -> '测试'
            const textWithoutAt = text.replace(/@_user_\d+/g, "");
            return textWithoutAt.trim();
        }
        catch {
            return "";
        }
    }
    /**
     * 获取原始文本内容
     * @param body 事件消息体
     * @returns 原始文本内容
     */
    getRawMsgText(body) {
        try {
            const { text } = JSON.parse(body?.event?.message?.content);
            return text;
        }
        catch {
            return "";
        }
    }
    /**
     * 获取聊天类型
     * @param body 事件消息体
     * @returns 聊天类型
     */
    getChatType(body) {
        return body?.event?.message?.chat_type;
    }
    /**
     * 获取艾特信息
     * @param body 事件消息体
     * @returns 艾特信息
     */
    getMentions(body) {
        return body?.event?.message?.mentions;
    }
    /**
     * 获取艾特的机器人
     * @param body 事件消息体
     * @returns 艾特的机器人
     */
    getMentionedRobot(body) {
        const mentions = this.getMentions(body);
        // 返回第一个没有user_id的mention
        return mentions?.find((mention) => !mention.id?.user_id);
    }
    /**
     * 获取Action类型
     * @param body Action消息体
     * @returns Action类型
     */
    getActionType(body) {
        return body?.action?.tag;
    }
    /**
     * 获取Action参数
     * @param body Action消息体
     * @returns Action参数
     */
    getActionValue(body) {
        return body?.action?.value;
    }
    /**
     * 获取Action选项
     * @param body Action消息体
     * @returns Action选项
     */
    getActionOption(body) {
        return body?.action?.option;
    }
    /**
     * 获取对话流Id
     * @param body 事件消息体或Action消息体
     * @returns 对话流Id
     */
    getChatId(body) {
        if (this.getIsEvent(body))
            return body?.event?.message?.chat_id;
        if (this.getIsAction(body))
            return body?.open_chat_id;
        return "";
    }
    /**
     * 获取消息Id
     * @param body 事件消息体或Action消息体
     * @returns 消息Id
     */
    getMessageId(body) {
        if (this.getIsEvent(body))
            return body?.event?.message?.message_id;
        if (this.getIsAction(body))
            return body?.open_message_id;
        return "";
    }
    /**
     * 获取用户Id
     * @param body 事件消息体
     * @returns 用户Id
     */
    getUserId(body) {
        if (this.getIsEvent(body))
            return body?.event?.sender?.sender_id?.user_id;
        if (this.getIsAction(body))
            return body?.user_id;
        return "";
    }
    /**
     * 获取用户OpenId
     * @param body 事件消息体
     * @returns 用户OpenId
     */
    getOpenId(body) {
        if (this.getIsEvent(body))
            return body?.event?.sender?.sender_id?.open_id;
        if (this.getIsAction(body))
            return body?.open_id;
        return "";
    }
    /**
     * 是否艾特了机器人
     * @param name 机器人名字
     * @returns 是否艾特了机器人
     */
    isAtBot(name) {
        if (!this.mentions)
            return false;
        if (!this.isInGroup)
            return false;
        return this.mentions.some((m) => m.name === name);
    }
}
export default LarkBody;
//# sourceMappingURL=index.js.map